.. role:: hidden
    :class: hidden-section

gpytorch.constraints
===================================

.. automodule:: gpytorch.constraints
.. currentmodule:: gpytorch.constraints


Parameter Constraints
-----------------------------

:hidden:`Interval`
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: Interval
   :members:

:hidden:`GreaterThan`
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: GreaterThan
   :members:

:hidden:`Positive`
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: Positive
   :members:

:hidden:`LessThan`
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: LessThan
   :members:
